import { Constants } from "./Constants.js";
import { PingCompensatedCharacter } from "./PingCompensatedCharacter.js";
export class Priest extends PingCompensatedCharacter {
    ctype = "priest";
    async absorbSins(target) {
        if (!this.ready)
            throw new Error("We aren't ready yet [absorbSins].");
        const absorbed = new Promise((resolve, reject) => {
            const cooldownCheck = (data) => {
                if (/skill_timeout\s*\(\s*['"]absorb['"]\s*,?\s*(\d+\.?\d+?)?\s*\)/.test(data.code)) {
                    this.socket.off("eval", cooldownCheck);
                    resolve();
                }
            };
            setTimeout(() => {
                this.socket.off("eval", cooldownCheck);
                reject(`curse timeout (${Constants.TIMEOUT}ms)`);
            }, Constants.TIMEOUT);
            this.socket.on("eval", cooldownCheck);
        });
        this.socket.emit("skill", { id: target, name: "absorb" });
        return absorbed;
    }
    async curse(target) {
        if (!this.ready)
            throw new Error("We aren't ready yet [curse].");
        const response = this.getResponsePromise("curse");
        this.socket.emit("skill", { id: target, name: "curse" });
        return response;
    }
    async darkBlessing() {
        if (!this.ready)
            throw new Error("We aren't ready yet [darkBlessing].");
        const darkBlessed = new Promise((resolve, reject) => {
            const cooldownCheck = (data) => {
                if (/skill_timeout\s*\(\s*['"]darkblessing['"]\s*,?\s*(\d+\.?\d+?)?\s*\)/.test(data.code)) {
                    this.socket.off("eval", cooldownCheck);
                    resolve();
                }
            };
            setTimeout(() => {
                this.socket.off("eval", cooldownCheck);
                reject(`darkblessing timeout (${Constants.TIMEOUT}ms)`);
            }, Constants.TIMEOUT);
            this.socket.on("eval", cooldownCheck);
        });
        this.socket.emit("skill", { name: "darkblessing" });
        return darkBlessed;
    }
    async heal(id) {
        if (!this.ready)
            throw new Error("We aren't ready yet [heal].");
        let projectile;
        const getProjectile = (data) => {
            if (data.attacker == this.id
                && data.type == "heal"
                && data.target == id) {
                projectile = data.pid;
            }
        };
        this.socket.on("action", getProjectile);
        try {
            const response = this.getResponsePromise("heal");
            this.socket.emit("heal", { id: id });
            await response;
        }
        finally {
            this.socket.off("action", getProjectile);
        }
        return projectile;
    }
    async partyHeal() {
        if (!this.ready)
            throw new Error("We aren't ready yet [partyHeal].");
        const healStarted = new Promise((resolve, reject) => {
            const cooldownCheck = (data) => {
                if (/skill_timeout\s*\(\s*['"]partyheal['"]\s*,?\s*(\d+\.?\d+?)?\s*\)/.test(data.code)) {
                    this.socket.off("eval", cooldownCheck);
                    resolve();
                }
            };
            setTimeout(() => {
                this.socket.off("eval", cooldownCheck);
                reject(`partyHeal timeout (${Constants.TIMEOUT}ms)`);
            }, Constants.TIMEOUT);
            this.socket.on("eval", cooldownCheck);
        });
        this.socket.emit("skill", { name: "partyheal" });
        return healStarted;
    }
    // NOTE: Untested. We might need to increase the timeout?
    async revive(target, essenceOfLife = this.locateItem("essenceoflife")) {
        if (!this.ready)
            throw new Error("We aren't ready yet [revive].");
        if (essenceOfLife === undefined)
            throw new Error("We don't have any essenceoflife in our inventory.");
        const revived = new Promise((resolve, reject) => {
            const cooldownCheck = (data) => {
                if (/skill_timeout\s*\(\s*['"]revive['"]\s*,?\s*(\d+\.?\d+?)?\s*\)/.test(data.code)) {
                    this.socket.off("eval", cooldownCheck);
                    resolve();
                }
            };
            setTimeout(() => {
                this.socket.off("eval", cooldownCheck);
                reject(`revive timeout (${Constants.TIMEOUT}ms)`);
            }, Constants.TIMEOUT);
            this.socket.on("eval", cooldownCheck);
        });
        this.socket.emit("skill", { id: target, name: "revive", num: essenceOfLife });
        return revived;
    }
}
//# sourceMappingURL=Priest.js.map